'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = createService;

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

var _feathersErrors = require('feathers-errors');

var _feathersErrors2 = _interopRequireDefault(_feathersErrors);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var debug = (0, _debug2.default)('feathers-stripe-webhooks:service');

function fetchEvent(stripe, eventId) {
  return new Promise(function (resolve, reject) {
    stripe.events.retrieve(eventId, function (err, event) {
      if (err) {
        return reject(err);
      }

      resolve(event);
    });
  });
}

function getHandler(handlers, data) {
  var parts = data.type.split('.');
  var node = handlers;
  for (var p in parts) {
    node = node[parts[p]];
    if (!node) {
      return undefined;
    }
  }

  return node;
}

function createService(stripe, handlers, options) {
  return {
    setup: function setup(app) {
      this.app = app;
    },
    create: function create(data) {
      var handler = getHandler(handlers, data);
      var app = this.app;
      if (!handler) {
        debug('Event type ' + data.type + ' is unhandled. Nothing to do.');
        return Promise.resolve({});
      }

      var eventData = options.verifyEvents ? fetchEvent(stripe, data.id) : Promise.resolve(data);

      return eventData.then(function (event) {
        // SECURITY: Check that the event types match the given (unverified) data to
        // ensure that the handler we are calling is not supplied by an attacker.
        if (event.type !== data.type) {
          debug('POSSIBLE ATTACK! Handler type from fetched stripe event is different from given event!');
          throw new _feathersErrors2.default.BadRequest('Invalid event');
        }

        return handler({ object: event.data.object, event: event, app: app });
      }).catch(function (err) {
        throw new _feathersErrors2.default.BadRequest(err.message);
      });
    }
  };
}
module.exports = exports['default'];